@@ -28,7 +28,7 @@ struct _EditorPageClass
 	GtkVBoxClass parent_class;
 };
 
-GtkType editor_page_get_type (void);
+GType editor_page_get_type (void);
 
 GtkWidget* editor_page_new (void);
 GtkWidget* editor_page_new_from_type (MtmEnv *env, gchar *type);
