@@ -38,14 +38,14 @@ mtm_handler_destroy (GtkObject *object)
 }
 
 static void
-mtm_handler_class_init (GtkObjectClass *object_class)
+mtm_handler_class_init (GObjectClass *object_class)
 {
 	mtm_handler_parent_class = gtk_type_class (mtm_stateful_get_type ());
-	object_class->destroy = mtm_handler_destroy;
+	GTK_OBJECT_CLASS (object_class)->destroy = mtm_handler_destroy;
 }
 
 static void
-mtm_handler_init (GtkObject *object)
+mtm_handler_init (GObject *object)
 {
 	MtmHandler *handler = MTM_HANDLER (object);
 	handler->cleanup_handler = mtm_handler_default_cleanup;
@@ -60,26 +60,30 @@ mtm_handler_init (GtkObject *object)
  * 
  * Return value: The type ID of the #MtmHandler class.
  */
-GtkType
+GType
 mtm_handler_get_type (void)
 {
-	static GtkType type = 0;
+	static GType type = 0;
 
 	if (!type)
 	{
-		GtkTypeInfo info =
+		GTypeInfo info =
 		{
-			"MtmHandler",
-			sizeof (MtmHandler),
 			sizeof (MtmHandlerClass),
-			(GtkClassInitFunc) mtm_handler_class_init,
-			(GtkObjectInitFunc) mtm_handler_init,
-			/* reserved_1 */ NULL,
-			/* reserved_2 */ NULL,
-			(GtkClassInitFunc) NULL
+			NULL,
+			NULL,
+			(GClassInitFunc) mtm_handler_class_init,
+			NULL,
+			NULL,
+			sizeof (MtmHandler),
+			0,	
+			(GInstanceInitFunc) mtm_handler_init,
+			NULL
 		};
 
-		type = gtk_type_unique (mtm_stateful_get_type (), &info);
+		type = g_type_register_static (MTM_STATEFUL_TYPE,
+					       "MtmHandler",
+					       &info, 0);
 	}
 
 	return type;
